@@ -9,8 +9,13 @@ from .supermetrics_to_azure_sql import SupermetricsToAzureSQL
 from .adls_container_to_container import ADLSContainerToContainer
 from .sharepoint_to_adls import SharepointToADLS
 from .cloud_for_customers_report_to_adls import CloudForCustomersReportToADLS
+from .aselite_to_adls import ASELiteToADLS
 
 try:
     from .sap_to_duckdb import SAPToDuckDB
 except ImportError:
     pass
+
+from .duckdb_transform import DuckDBTransform
+from .duckdb_to_sql_server import DuckDBToSQLServer
+from .multiple_flows import MultipleFlows
