@@ -18,6 +18,17 @@ class AzureSQLTransform(Flow):
         *args: List[any],
         **kwargs: Dict[str, Any]
     ):
+        """
+        Flow for running SQL queries on top of Azure SQL Database.
+
+        Args:
+            name (str): The name of the flow.
+            query (str, required): The query to execute on the database.
+            credentials_secret (str, optional): The name of the Azure Key Vault secret containing a dictionary
+            with SQL db credentials (server, db_name, user, and password).
+            vault_name (str, optional): The name of the vault from which to obtain the secret. Defaults to None.
+            tags (list, optional): Tag for marking flow. Defaults to "transform".
+        """
         self.query = query
         self.tags = tags
         self.sqldb_credentials_secret = sqldb_credentials_secret
