@@ -27,7 +27,7 @@ from .sqlite import SQLiteInsert, SQLiteSQLtoDF, SQLiteQuery
 from .supermetrics import SupermetricsToCSV, SupermetricsToDF
 from .sharepoint import SharepointToDF
 from .cloud_for_customers import C4CReportToDF, C4CToDF
-from .prefect import GetFlowNewDateRange
+from .prefect_date_range import GetFlowNewDateRange
 from .aselite import ASELiteToDF
 
 try:
